@@ -40,12 +40,11 @@ def parse_defines(defines_str):
     return defines
 
 def run_minimize(exp, pipeline_depth): 
-    if pipeline_depth is not None:
-        print("Pipeline_depth was given to run_minimize : it will be ignored")
     handler = exp_strategy.CSVHandler('{}.csv'.format(exp.name.strip()))
     exp_strategy.minimize_latency(
         exp,
-        [handler]
+        [handler],
+        pipeline_depth
     )
 
 def run_implement(exp, pipeline_depth):
@@ -69,11 +68,13 @@ def run_meta_exp(name, config, config_path, command, export_hls, export_ip):
     hdl_name = config['hdl'] if 'hdl' in config else 'vhdl'
     hdl = vivado_exp.HDL.VERILOG if hdl_name == 'verilog' else vivado_exp.HDL.VHDL
     no_pipeline = (config['no_pipeline'].strip().lower() == "true") if 'no_pipeline' in config else False
+    no_inline = (config['no_inline'].strip().lower() == "true") if 'no_inline' in config else False
     ap_ctrl_hs = (config['ctrl_hs'].strip().lower() == "true") if 'ctrl_hs' in config else False
     exp_type_dict = {'hls' : vivado_exp.ExperienceType.CSYNTH_ONLY,
                      'syn' : vivado_exp.ExperienceType.SYNTHESIS,
                      'impl': vivado_exp.ExperienceType.IMPLEMENTATION}
     exp_type = exp_type_dict[config['exp_type']] if 'exp_type' in config else vivado_exp.ExperienceType.IMPLEMENTATION
+    regout = (not (config['no_reg_out'].strip.lower() == "true")) if 'no_reg_out' in config else True
     exp = vivado_exp.Experiment(
         name,
         comp_path,
@@ -84,6 +85,7 @@ def run_meta_exp(name, config, config_path, command, export_hls, export_ip):
         hdl,
         exp_type,
         not no_pipeline,
+        not no_inline,
         ap_ctrl_hs,
         keep_env,
         description=description,
