@@ -6,9 +6,22 @@ import typing
 _opt_str = typing.Optional[str]
 
 
-def create_project(file, project_name, filename, comp_name, includes, defines,
-                   standard, solution_name, part, period, pipeline, ctrl_hs,
-                   depth_constraint):
+def create_project(
+    file, 
+    project_name, 
+    filename, 
+    comp_name, 
+    includes, 
+    defines,
+    standard, 
+    solution_name, 
+    part, 
+    period,
+    pipeline,
+    inline,
+    ctrl_hs,
+    depth_constraint,
+    register_outputs):
     """
     Generate a tcl script for an HLS component creation
     :param filename: name of the file containing hls code
@@ -22,8 +35,10 @@ def create_project(file, project_name, filename, comp_name, includes, defines,
     :param defines: list of defines
     :param standard: c++ standard code to use
     :param pipeline: should vivado pipeline the design
+    :param inline: should vivado inline fully function calls
     :param ctrl_hs: should the design be wrapped with ap_ctrl_hs control signals
     :depth_constraint: depth_constraint to set
+    :register_outputs: should the function ouptut be buffered
     """
     file.write("open_project {}\n".format(project_name))
     file.write("set_top {}\n".format(comp_name))
@@ -53,7 +68,8 @@ def create_project(file, project_name, filename, comp_name, includes, defines,
     ctrl_mode = 'ap_ctrl_hs' if ctrl_hs else 'ap_ctrl_none'
     file.write(f'set_directive_interface -mode {ctrl_mode} [get_top]\n')
     file.write('config_schedule -relax_ii_for_timing=0 -effort high\n')
-    file.write('set_directive_inline -recursive [get_top]\n')
+    if inline:
+        file.write('set_directive_inline -recursive [get_top]\n')
     reg_type = "scalar_out"
     if pipeline:
         file.write('set_directive_pipeline -II 1 [get_top]\n')
@@ -62,7 +78,8 @@ def create_project(file, project_name, filename, comp_name, includes, defines,
             reg_type = 'scalar_all'
             depth_constraint = 2
         file.write('set_directive_latency -min {} -max {} [get_top]\n'.format(depth_constraint, depth_constraint))
-    file.write(f'config_interface -register_io {reg_type}\n')
+    if register_outputs and (depth_constraint is None or depth_constraint > 0):
+        file.write(f'config_interface -register_io {reg_type}\n')
 
 def csynth_solution_script(file):
     """Generate a script in file for synthetizing solution solution_name of project project_name"""
