@@ -5,6 +5,7 @@ Parse vivado hls report
 from pathlib import Path
 import re
 from xml.dom import minidom
+from itertools import dropwhile
 
 def __getText(nodelist):
     rc = []
@@ -52,3 +53,17 @@ def parse_impl_report(impl_report_file):
     res["timing"] = __getText(timing.getElementsByTagName('AchievedClockPeriod')[0].childNodes)
     return res
 
+
+def _parse_timing(line):
+    pattern = '(?P<val>[0-9]+\.[0-9]+)ns'
+    match = re.search(pattern, line)
+    return match.group('val')
+
+def parse_timing_report(timing_report_path):
+    line_filter = lambda x : not x.startswith('Timing Report')
+    with timing_report_path.open('r') as timing_report:
+        for line in dropwhile(line_filter,  timing_report):
+            if line.strip().startswith('Data Path Delay:'):
+                timing = _parse_timing(line)
+                return timing
+
